All Classes and Interfaces

Classes
Class
Description
 
This middleware handler is responsible for decode gzip request body in the request chain.
 
This is a middleware handler that you can wire in to the response chain to gzip large content body in order to speed up the delivery and reduce the bandwidth usage.